@@ -194,7 +194,7 @@ void AutoProjectWidget::initDetailview ( QWidget* parent )
 	executeTargetButton->setPixmap( SmallIcon( "exec") );
 	QToolTip::add
 		( executeTargetButton, i18n( "Execute" ) );
-    QWhatsThis::add(executeTargetButton, i18n("<b>Execute target</b><p> Executes target, if it's a program. Tries to build it, if that's not yet done."));					    
+    QWhatsThis::add(executeTargetButton, i18n("<b>Execute target</b><p> Executes target, if it is a program. Tries to build it, if that is not yet done."));					    
 
 	QWidget *spacer2 = new QWidget( targetButtonBox );
 	targetButtonBox->setStretchFactor( spacer2, 1 );
@@ -217,7 +217,7 @@ void AutoProjectWidget::initDetailview ( QWidget* parent )
 	m_detailView = new AutoDetailsView( this, m_part, targetBox, "project details widget" );
 	m_detailView->setRootIsDecorated( true );
 	m_detailView->setResizeMode( QListView::LastColumn );
-	m_detailView->setSorting( -1 );
+//	m_detailView->setSorting( -1 );
 	m_detailView->header() ->hide();
 	m_detailView->addColumn( QString::null );
 }
