@@ -47,7 +47,6 @@
 #include <kdialogbase.h>
 #include <kgenericfactory.h>
 #include <klocale.h>
-#include <kmessagebox.h>
 #include <kmainwindow.h>
 #include <kstatusbar.h>
 #include <kconfig.h>
@@ -128,7 +127,7 @@ public:
 };
 
 JavaSupportPart::JavaSupportPart(QObject *parent, const char *name, const QStringList &/*args*/)
-    : KDevLanguageSupport("JavaSupport", "java", parent, name ? name : "KDevJavaSupport"),
+    : KDevLanguageSupport(JavaSupportFactory::info(), parent, name ? name : "KDevJavaSupport"),
       m_activeDocument( 0 ), m_activeView( 0 ), m_activeSelection( 0 ), m_activeEditor( 0 ),
       m_activeViewCursor( 0 ), m_projectClosed( true ), m_valid( false )
 {
@@ -738,7 +737,7 @@ void JavaSupportPart::setupCatalog( )
 
     if( pcsList.size() && pcsVersion() < KDEV_DB_VERSION ){
         QStringList l = pcsList + pcsIdxList;
-        int rtn = KMessageBox::questionYesNoList( 0, i18n("Persistant class store will be disabled!! You have a wrong version of pcs installed.\nRemove old pcs files?"), l, i18n("Java Support") );
+        int rtn = KMessageBox::questionYesNoList( 0, i18n("Persistant class store will be disabled: you have a wrong version of pcs installed.\nRemove old pcs files?"), l, i18n("Java Support") );
         if( rtn == KMessageBox::Yes ){
             QStringList::Iterator it = l.begin();
             while( it != l.end() ){
