@@ -24,7 +24,7 @@
 #include "rdbcontroller.h"
 
 #include <sys/types.h> 
-#include <sys/fcntl.h>
+#include <fcntl.h>
 #include <sys/socket.h> 
 #include <sys/un.h>
 #include <errno.h>
